# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['RuleArgs', 'Rule']

@pulumi.input_type
class RuleArgs:
    def __init__(__self__, *,
                 category: pulumi.Input[int],
                 content: pulumi.Input[str],
                 rule_name: pulumi.Input[str],
                 content_category: Optional[pulumi.Input[str]] = None,
                 custom_type: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 product_id: Optional[pulumi.Input[str]] = None,
                 risk_level_id: Optional[pulumi.Input[str]] = None,
                 rule_type: Optional[pulumi.Input[int]] = None,
                 stat_express: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 warn_level: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Rule resource.
        :param pulumi.Input[int] category: Sensitive Data Identification Rules for the Type of. Valid values:
        :param pulumi.Input[str] content: Sensitive Data Identification Rules the Content.
        :param pulumi.Input[str] rule_name: Sensitive Data Identification Name of the Rule.
        :param pulumi.Input[str] content_category: The Content Classification.
        :param pulumi.Input[int] custom_type: Sensitive Data Identification Rules of Type. Valid values:
        :param pulumi.Input[str] description: Sensitive Data Identification a Description of the Rule Information.
        :param pulumi.Input[str] lang: The Request and Receive the Language of the Message Type. Valid values:
        :param pulumi.Input[str] product_code: Product Code. Valid values: `OSS`,`RDS`,`ODPS`(MaxCompute).
        :param pulumi.Input[str] product_id: Product ID. Valid values:
        :param pulumi.Input[str] risk_level_id: Sensitive Data Identification Rules of Risk Level ID. Valid values:
        :param pulumi.Input[int] rule_type: Rule Type.
        :param pulumi.Input[str] stat_express: Triggered the Alarm Conditions.
        :param pulumi.Input[int] status: Sensitive Data Identification Rules Detection State of.
        :param pulumi.Input[str] target: The Target of rule.
        :param pulumi.Input[int] warn_level: The Level of Risk. Valid values:
        """
        pulumi.set(__self__, "category", category)
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "rule_name", rule_name)
        if content_category is not None:
            pulumi.set(__self__, "content_category", content_category)
        if custom_type is not None:
            pulumi.set(__self__, "custom_type", custom_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if product_code is not None:
            pulumi.set(__self__, "product_code", product_code)
        if product_id is not None:
            pulumi.set(__self__, "product_id", product_id)
        if risk_level_id is not None:
            pulumi.set(__self__, "risk_level_id", risk_level_id)
        if rule_type is not None:
            pulumi.set(__self__, "rule_type", rule_type)
        if stat_express is not None:
            pulumi.set(__self__, "stat_express", stat_express)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if warn_level is not None:
            pulumi.set(__self__, "warn_level", warn_level)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Input[int]:
        """
        Sensitive Data Identification Rules for the Type of. Valid values:
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: pulumi.Input[int]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter
    def content(self) -> pulumi.Input[str]:
        """
        Sensitive Data Identification Rules the Content.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[str]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Input[str]:
        """
        Sensitive Data Identification Name of the Rule.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="contentCategory")
    def content_category(self) -> Optional[pulumi.Input[str]]:
        """
        The Content Classification.
        """
        return pulumi.get(self, "content_category")

    @content_category.setter
    def content_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_category", value)

    @property
    @pulumi.getter(name="customType")
    def custom_type(self) -> Optional[pulumi.Input[int]]:
        """
        Sensitive Data Identification Rules of Type. Valid values:
        """
        return pulumi.get(self, "custom_type")

    @custom_type.setter
    def custom_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "custom_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Sensitive Data Identification a Description of the Rule Information.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        The Request and Receive the Language of the Message Type. Valid values:
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> Optional[pulumi.Input[str]]:
        """
        Product Code. Valid values: `OSS`,`RDS`,`ODPS`(MaxCompute).
        """
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> Optional[pulumi.Input[str]]:
        """
        Product ID. Valid values:
        """
        return pulumi.get(self, "product_id")

    @product_id.setter
    def product_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_id", value)

    @property
    @pulumi.getter(name="riskLevelId")
    def risk_level_id(self) -> Optional[pulumi.Input[str]]:
        """
        Sensitive Data Identification Rules of Risk Level ID. Valid values:
        """
        return pulumi.get(self, "risk_level_id")

    @risk_level_id.setter
    def risk_level_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "risk_level_id", value)

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> Optional[pulumi.Input[int]]:
        """
        Rule Type.
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rule_type", value)

    @property
    @pulumi.getter(name="statExpress")
    def stat_express(self) -> Optional[pulumi.Input[str]]:
        """
        Triggered the Alarm Conditions.
        """
        return pulumi.get(self, "stat_express")

    @stat_express.setter
    def stat_express(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stat_express", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        """
        Sensitive Data Identification Rules Detection State of.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[str]]:
        """
        The Target of rule.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="warnLevel")
    def warn_level(self) -> Optional[pulumi.Input[int]]:
        """
        The Level of Risk. Valid values:
        """
        return pulumi.get(self, "warn_level")

    @warn_level.setter
    def warn_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "warn_level", value)


@pulumi.input_type
class _RuleState:
    def __init__(__self__, *,
                 category: Optional[pulumi.Input[int]] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 content_category: Optional[pulumi.Input[str]] = None,
                 custom_type: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 product_id: Optional[pulumi.Input[str]] = None,
                 risk_level_id: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 rule_type: Optional[pulumi.Input[int]] = None,
                 stat_express: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 warn_level: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Rule resources.
        :param pulumi.Input[int] category: Sensitive Data Identification Rules for the Type of. Valid values:
        :param pulumi.Input[str] content: Sensitive Data Identification Rules the Content.
        :param pulumi.Input[str] content_category: The Content Classification.
        :param pulumi.Input[int] custom_type: Sensitive Data Identification Rules of Type. Valid values:
        :param pulumi.Input[str] description: Sensitive Data Identification a Description of the Rule Information.
        :param pulumi.Input[str] lang: The Request and Receive the Language of the Message Type. Valid values:
        :param pulumi.Input[str] product_code: Product Code. Valid values: `OSS`,`RDS`,`ODPS`(MaxCompute).
        :param pulumi.Input[str] product_id: Product ID. Valid values:
        :param pulumi.Input[str] risk_level_id: Sensitive Data Identification Rules of Risk Level ID. Valid values:
        :param pulumi.Input[str] rule_name: Sensitive Data Identification Name of the Rule.
        :param pulumi.Input[int] rule_type: Rule Type.
        :param pulumi.Input[str] stat_express: Triggered the Alarm Conditions.
        :param pulumi.Input[int] status: Sensitive Data Identification Rules Detection State of.
        :param pulumi.Input[str] target: The Target of rule.
        :param pulumi.Input[int] warn_level: The Level of Risk. Valid values:
        """
        if category is not None:
            pulumi.set(__self__, "category", category)
        if content is not None:
            pulumi.set(__self__, "content", content)
        if content_category is not None:
            pulumi.set(__self__, "content_category", content_category)
        if custom_type is not None:
            pulumi.set(__self__, "custom_type", custom_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if product_code is not None:
            pulumi.set(__self__, "product_code", product_code)
        if product_id is not None:
            pulumi.set(__self__, "product_id", product_id)
        if risk_level_id is not None:
            pulumi.set(__self__, "risk_level_id", risk_level_id)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if rule_type is not None:
            pulumi.set(__self__, "rule_type", rule_type)
        if stat_express is not None:
            pulumi.set(__self__, "stat_express", stat_express)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if warn_level is not None:
            pulumi.set(__self__, "warn_level", warn_level)

    @property
    @pulumi.getter
    def category(self) -> Optional[pulumi.Input[int]]:
        """
        Sensitive Data Identification Rules for the Type of. Valid values:
        """
        return pulumi.get(self, "category")

    @category.setter
    def category(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "category", value)

    @property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[str]]:
        """
        Sensitive Data Identification Rules the Content.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content", value)

    @property
    @pulumi.getter(name="contentCategory")
    def content_category(self) -> Optional[pulumi.Input[str]]:
        """
        The Content Classification.
        """
        return pulumi.get(self, "content_category")

    @content_category.setter
    def content_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_category", value)

    @property
    @pulumi.getter(name="customType")
    def custom_type(self) -> Optional[pulumi.Input[int]]:
        """
        Sensitive Data Identification Rules of Type. Valid values:
        """
        return pulumi.get(self, "custom_type")

    @custom_type.setter
    def custom_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "custom_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Sensitive Data Identification a Description of the Rule Information.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        The Request and Receive the Language of the Message Type. Valid values:
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> Optional[pulumi.Input[str]]:
        """
        Product Code. Valid values: `OSS`,`RDS`,`ODPS`(MaxCompute).
        """
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> Optional[pulumi.Input[str]]:
        """
        Product ID. Valid values:
        """
        return pulumi.get(self, "product_id")

    @product_id.setter
    def product_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_id", value)

    @property
    @pulumi.getter(name="riskLevelId")
    def risk_level_id(self) -> Optional[pulumi.Input[str]]:
        """
        Sensitive Data Identification Rules of Risk Level ID. Valid values:
        """
        return pulumi.get(self, "risk_level_id")

    @risk_level_id.setter
    def risk_level_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "risk_level_id", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[str]]:
        """
        Sensitive Data Identification Name of the Rule.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> Optional[pulumi.Input[int]]:
        """
        Rule Type.
        """
        return pulumi.get(self, "rule_type")

    @rule_type.setter
    def rule_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "rule_type", value)

    @property
    @pulumi.getter(name="statExpress")
    def stat_express(self) -> Optional[pulumi.Input[str]]:
        """
        Triggered the Alarm Conditions.
        """
        return pulumi.get(self, "stat_express")

    @stat_express.setter
    def stat_express(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stat_express", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        """
        Sensitive Data Identification Rules Detection State of.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[str]]:
        """
        The Target of rule.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="warnLevel")
    def warn_level(self) -> Optional[pulumi.Input[int]]:
        """
        The Level of Risk. Valid values:
        """
        return pulumi.get(self, "warn_level")

    @warn_level.setter
    def warn_level(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "warn_level", value)


class Rule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[int]] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 content_category: Optional[pulumi.Input[str]] = None,
                 custom_type: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 product_id: Optional[pulumi.Input[str]] = None,
                 risk_level_id: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 rule_type: Optional[pulumi.Input[int]] = None,
                 stat_express: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 warn_level: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a Data Security Center Rule resource.

        For information about Data Security Center Rule and how to use it, see [What is Rule](https://help.aliyun.com/product/88674.html).

        > **NOTE:** Available in v1.132.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.sddp.Rule("default",
            category=0,
            content="content",
            product_code="ODPS",
            risk_level_id="4",
            rule_name="rule_name")
        ```

        ## Import

        Data Security Center Rule can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:sddp/rule:Rule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] category: Sensitive Data Identification Rules for the Type of. Valid values:
        :param pulumi.Input[str] content: Sensitive Data Identification Rules the Content.
        :param pulumi.Input[str] content_category: The Content Classification.
        :param pulumi.Input[int] custom_type: Sensitive Data Identification Rules of Type. Valid values:
        :param pulumi.Input[str] description: Sensitive Data Identification a Description of the Rule Information.
        :param pulumi.Input[str] lang: The Request and Receive the Language of the Message Type. Valid values:
        :param pulumi.Input[str] product_code: Product Code. Valid values: `OSS`,`RDS`,`ODPS`(MaxCompute).
        :param pulumi.Input[str] product_id: Product ID. Valid values:
        :param pulumi.Input[str] risk_level_id: Sensitive Data Identification Rules of Risk Level ID. Valid values:
        :param pulumi.Input[str] rule_name: Sensitive Data Identification Name of the Rule.
        :param pulumi.Input[int] rule_type: Rule Type.
        :param pulumi.Input[str] stat_express: Triggered the Alarm Conditions.
        :param pulumi.Input[int] status: Sensitive Data Identification Rules Detection State of.
        :param pulumi.Input[str] target: The Target of rule.
        :param pulumi.Input[int] warn_level: The Level of Risk. Valid values:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Security Center Rule resource.

        For information about Data Security Center Rule and how to use it, see [What is Rule](https://help.aliyun.com/product/88674.html).

        > **NOTE:** Available in v1.132.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.sddp.Rule("default",
            category=0,
            content="content",
            product_code="ODPS",
            risk_level_id="4",
            rule_name="rule_name")
        ```

        ## Import

        Data Security Center Rule can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:sddp/rule:Rule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param RuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 category: Optional[pulumi.Input[int]] = None,
                 content: Optional[pulumi.Input[str]] = None,
                 content_category: Optional[pulumi.Input[str]] = None,
                 custom_type: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 product_id: Optional[pulumi.Input[str]] = None,
                 risk_level_id: Optional[pulumi.Input[str]] = None,
                 rule_name: Optional[pulumi.Input[str]] = None,
                 rule_type: Optional[pulumi.Input[int]] = None,
                 stat_express: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 warn_level: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RuleArgs.__new__(RuleArgs)

            if category is None and not opts.urn:
                raise TypeError("Missing required property 'category'")
            __props__.__dict__["category"] = category
            if content is None and not opts.urn:
                raise TypeError("Missing required property 'content'")
            __props__.__dict__["content"] = content
            __props__.__dict__["content_category"] = content_category
            __props__.__dict__["custom_type"] = custom_type
            __props__.__dict__["description"] = description
            __props__.__dict__["lang"] = lang
            __props__.__dict__["product_code"] = product_code
            __props__.__dict__["product_id"] = product_id
            __props__.__dict__["risk_level_id"] = risk_level_id
            if rule_name is None and not opts.urn:
                raise TypeError("Missing required property 'rule_name'")
            __props__.__dict__["rule_name"] = rule_name
            __props__.__dict__["rule_type"] = rule_type
            __props__.__dict__["stat_express"] = stat_express
            __props__.__dict__["status"] = status
            __props__.__dict__["target"] = target
            __props__.__dict__["warn_level"] = warn_level
        super(Rule, __self__).__init__(
            'alicloud:sddp/rule:Rule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            category: Optional[pulumi.Input[int]] = None,
            content: Optional[pulumi.Input[str]] = None,
            content_category: Optional[pulumi.Input[str]] = None,
            custom_type: Optional[pulumi.Input[int]] = None,
            description: Optional[pulumi.Input[str]] = None,
            lang: Optional[pulumi.Input[str]] = None,
            product_code: Optional[pulumi.Input[str]] = None,
            product_id: Optional[pulumi.Input[str]] = None,
            risk_level_id: Optional[pulumi.Input[str]] = None,
            rule_name: Optional[pulumi.Input[str]] = None,
            rule_type: Optional[pulumi.Input[int]] = None,
            stat_express: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[int]] = None,
            target: Optional[pulumi.Input[str]] = None,
            warn_level: Optional[pulumi.Input[int]] = None) -> 'Rule':
        """
        Get an existing Rule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] category: Sensitive Data Identification Rules for the Type of. Valid values:
        :param pulumi.Input[str] content: Sensitive Data Identification Rules the Content.
        :param pulumi.Input[str] content_category: The Content Classification.
        :param pulumi.Input[int] custom_type: Sensitive Data Identification Rules of Type. Valid values:
        :param pulumi.Input[str] description: Sensitive Data Identification a Description of the Rule Information.
        :param pulumi.Input[str] lang: The Request and Receive the Language of the Message Type. Valid values:
        :param pulumi.Input[str] product_code: Product Code. Valid values: `OSS`,`RDS`,`ODPS`(MaxCompute).
        :param pulumi.Input[str] product_id: Product ID. Valid values:
        :param pulumi.Input[str] risk_level_id: Sensitive Data Identification Rules of Risk Level ID. Valid values:
        :param pulumi.Input[str] rule_name: Sensitive Data Identification Name of the Rule.
        :param pulumi.Input[int] rule_type: Rule Type.
        :param pulumi.Input[str] stat_express: Triggered the Alarm Conditions.
        :param pulumi.Input[int] status: Sensitive Data Identification Rules Detection State of.
        :param pulumi.Input[str] target: The Target of rule.
        :param pulumi.Input[int] warn_level: The Level of Risk. Valid values:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RuleState.__new__(_RuleState)

        __props__.__dict__["category"] = category
        __props__.__dict__["content"] = content
        __props__.__dict__["content_category"] = content_category
        __props__.__dict__["custom_type"] = custom_type
        __props__.__dict__["description"] = description
        __props__.__dict__["lang"] = lang
        __props__.__dict__["product_code"] = product_code
        __props__.__dict__["product_id"] = product_id
        __props__.__dict__["risk_level_id"] = risk_level_id
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["rule_type"] = rule_type
        __props__.__dict__["stat_express"] = stat_express
        __props__.__dict__["status"] = status
        __props__.__dict__["target"] = target
        __props__.__dict__["warn_level"] = warn_level
        return Rule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def category(self) -> pulumi.Output[int]:
        """
        Sensitive Data Identification Rules for the Type of. Valid values:
        """
        return pulumi.get(self, "category")

    @property
    @pulumi.getter
    def content(self) -> pulumi.Output[str]:
        """
        Sensitive Data Identification Rules the Content.
        """
        return pulumi.get(self, "content")

    @property
    @pulumi.getter(name="contentCategory")
    def content_category(self) -> pulumi.Output[str]:
        """
        The Content Classification.
        """
        return pulumi.get(self, "content_category")

    @property
    @pulumi.getter(name="customType")
    def custom_type(self) -> pulumi.Output[int]:
        """
        Sensitive Data Identification Rules of Type. Valid values:
        """
        return pulumi.get(self, "custom_type")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Sensitive Data Identification a Description of the Rule Information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def lang(self) -> pulumi.Output[Optional[str]]:
        """
        The Request and Receive the Language of the Message Type. Valid values:
        """
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> pulumi.Output[Optional[str]]:
        """
        Product Code. Valid values: `OSS`,`RDS`,`ODPS`(MaxCompute).
        """
        return pulumi.get(self, "product_code")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> pulumi.Output[Optional[str]]:
        """
        Product ID. Valid values:
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="riskLevelId")
    def risk_level_id(self) -> pulumi.Output[Optional[str]]:
        """
        Sensitive Data Identification Rules of Risk Level ID. Valid values:
        """
        return pulumi.get(self, "risk_level_id")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[str]:
        """
        Sensitive Data Identification Name of the Rule.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="ruleType")
    def rule_type(self) -> pulumi.Output[Optional[int]]:
        """
        Rule Type.
        """
        return pulumi.get(self, "rule_type")

    @property
    @pulumi.getter(name="statExpress")
    def stat_express(self) -> pulumi.Output[Optional[str]]:
        """
        Triggered the Alarm Conditions.
        """
        return pulumi.get(self, "stat_express")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[int]:
        """
        Sensitive Data Identification Rules Detection State of.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output[Optional[str]]:
        """
        The Target of rule.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter(name="warnLevel")
    def warn_level(self) -> pulumi.Output[Optional[int]]:
        """
        The Level of Risk. Valid values:
        """
        return pulumi.get(self, "warn_level")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .account import *
from .control_policy import *
from .control_policy_attachment import *
from .delegated_administrator import *
from .folder import *
from .get_account_deletion_check_task import *
from .get_accounts import *
from .get_control_policies import *
from .get_control_policy_attachments import *
from .get_delegated_administrators import *
from .get_folders import *
from .get_handshakes import *
from .get_policies import *
from .get_policy_attachments import *
from .get_policy_versions import *
from .get_resource_directories import *
from .get_resource_groups import *
from .get_resource_shares import *
from .get_roles import *
from .get_shared_resources import *
from .get_shared_targets import *
from .handshake import *
from .policy import *
from .policy_attachment import *
from .policy_version import *
from .resource_directory import *
from .resource_group import *
from .resource_share import *
from .role import *
from .service_linked_role import *
from .shared_resource import *
from .shared_target import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetEcsDeploymentSetsResult',
    'AwaitableGetEcsDeploymentSetsResult',
    'get_ecs_deployment_sets',
    'get_ecs_deployment_sets_output',
]

@pulumi.output_type
class GetEcsDeploymentSetsResult:
    """
    A collection of values returned by getEcsDeploymentSets.
    """
    def __init__(__self__, deployment_set_name=None, id=None, ids=None, name_regex=None, names=None, output_file=None, sets=None, strategy=None):
        if deployment_set_name and not isinstance(deployment_set_name, str):
            raise TypeError("Expected argument 'deployment_set_name' to be a str")
        pulumi.set(__self__, "deployment_set_name", deployment_set_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if sets and not isinstance(sets, list):
            raise TypeError("Expected argument 'sets' to be a list")
        pulumi.set(__self__, "sets", sets)
        if strategy and not isinstance(strategy, str):
            raise TypeError("Expected argument 'strategy' to be a str")
        pulumi.set(__self__, "strategy", strategy)

    @property
    @pulumi.getter(name="deploymentSetName")
    def deployment_set_name(self) -> Optional[str]:
        return pulumi.get(self, "deployment_set_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def sets(self) -> Sequence['outputs.GetEcsDeploymentSetsSetResult']:
        return pulumi.get(self, "sets")

    @property
    @pulumi.getter
    def strategy(self) -> Optional[str]:
        return pulumi.get(self, "strategy")


class AwaitableGetEcsDeploymentSetsResult(GetEcsDeploymentSetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEcsDeploymentSetsResult(
            deployment_set_name=self.deployment_set_name,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            sets=self.sets,
            strategy=self.strategy)


def get_ecs_deployment_sets(deployment_set_name: Optional[str] = None,
                            ids: Optional[Sequence[str]] = None,
                            name_regex: Optional[str] = None,
                            output_file: Optional[str] = None,
                            strategy: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEcsDeploymentSetsResult:
    """
    This data source provides the Ecs Deployment Sets of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.140.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ecs.get_ecs_deployment_sets(ids=["example_id"])
    pulumi.export("ecsDeploymentSetId1", ids.sets[0].id)
    name_regex = alicloud.ecs.get_ecs_deployment_sets(name_regex="^my-DeploymentSet")
    pulumi.export("ecsDeploymentSetId2", name_regex.sets[0].id)
    ```


    :param str deployment_set_name: The name of the deployment set.
    :param Sequence[str] ids: A list of Deployment Set IDs.
    :param str name_regex: A regex string to filter results by Deployment Set name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str strategy: The deployment strategy.
    """
    __args__ = dict()
    __args__['deploymentSetName'] = deployment_set_name
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['strategy'] = strategy
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:ecs/getEcsDeploymentSets:getEcsDeploymentSets', __args__, opts=opts, typ=GetEcsDeploymentSetsResult).value

    return AwaitableGetEcsDeploymentSetsResult(
        deployment_set_name=pulumi.get(__ret__, 'deployment_set_name'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        sets=pulumi.get(__ret__, 'sets'),
        strategy=pulumi.get(__ret__, 'strategy'))


@_utilities.lift_output_func(get_ecs_deployment_sets)
def get_ecs_deployment_sets_output(deployment_set_name: Optional[pulumi.Input[Optional[str]]] = None,
                                   ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                   name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                   output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                   strategy: Optional[pulumi.Input[Optional[str]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEcsDeploymentSetsResult]:
    """
    This data source provides the Ecs Deployment Sets of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.140.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.ecs.get_ecs_deployment_sets(ids=["example_id"])
    pulumi.export("ecsDeploymentSetId1", ids.sets[0].id)
    name_regex = alicloud.ecs.get_ecs_deployment_sets(name_regex="^my-DeploymentSet")
    pulumi.export("ecsDeploymentSetId2", name_regex.sets[0].id)
    ```


    :param str deployment_set_name: The name of the deployment set.
    :param Sequence[str] ids: A list of Deployment Set IDs.
    :param str name_regex: A regex string to filter results by Deployment Set name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str strategy: The deployment strategy.
    """
    ...
